.. _ansible_community_guide:

***********************
Ansible Community Guide
***********************

Welcome to the Ansible Community Guide!

The purpose of this guide is to teach you everything you need to know about being a contributing member of the Ansible community.

To get started, please read and understand the :ref:`code_of_conduct`, and then select one of the following topics.

.. toctree::
   :maxdepth: 2

   code_of_conduct
   how_can_I_help
   reporting_bugs_and_features
   documentation_contributions
   communication
   development_process
   contributor_license_agreement
   triage_process
   other_tools_and_programs
   ../dev_guide/style_guide/index

.. toctree::
   :caption: Guidelines for specific types of contributors
   :maxdepth: 2

   committer_guidelines
   maintainers
   release_managers
   github_admins
